/**
  ******************************************************************************
  * @file    Multi/Examples/MotionControl/IHM05A1_ExampleFor1Motor/Src/main.c 
  * @author  IPC Rennes
  * @version V1.5.0
  * @date    June 1st, 2018
  * @brief   This example shows how to use 1 IHM05A1 expansion board
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; COPYRIGHT(c) 2016 STMicroelectronics</center></h2>
  *
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met:
  *   1. Redistributions of source code must retain the above copyright notice,
  *      this list of conditions and the following disclaimer.
  *   2. Redistributions in binary form must reproduce the above copyright notice,
  *      this list of conditions and the following disclaimer in the documentation
  *      and/or other materials provided with the distribution.
  *   3. Neither the name of STMicroelectronics nor the names of its contributors
  *      may be used to endorse or promote products derived from this software
  *      without specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/** @defgroup IHM05A1_Example_for_1_motor_device
  * @{
  */ 

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
UART_HandleTypeDef huart2;
static volatile uint16_t gLastError;
static volatile bool gButtonPressed = FALSE;
static volatile float sunWindow;

/* Initialization parameters. */
l6208_Init_t initDeviceParameters =
{
  1500,            //Acceleration rate in step/s^2 or (1/16)th step/s^2 for microstep modes
  20,              //Acceleration current torque in % (from 0 to 100)
  1500,            //Deceleration rate in step/s^2 or (1/16)th step/s^2 for microstep modes
  20,              //Deceleration current torque in % (from 0 to 100)
  1500,            //Running speed in step/s or (1/16)th step/s for microstep modes
  10,              //Running current torque in % (from 0 to 100)
  5,               //Holding current torque in % (from 0 to 100)
  STEP_MODE_1_16,  //Step mode via enum motorStepMode_t
  FAST_DECAY,      //Decay mode via enum motorDecayMode_t
  0,               //Dwelling time in ms
  FALSE,           //Automatic HIZ STOP
  100000           //VREFA and VREFB PWM frequency (Hz)
};
 
/* Private function prototypes -----------------------------------------------*/
static void MyFlagInterruptHandler(void);
void ButtonHandler(void);

/* Private functions ---------------------------------------------------------*/

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void)
{
	int32_t pos;
	uint32_t freqPwm, timeToNextStep;

	/* STM32xx HAL library initialization */
	HAL_Init();

	/* Configure the system clock */
	SystemClock_Config();

	//----- Init of the Motor control library
	/* Set the L6208 library to use 1 device */
	BSP_MotorControl_SetNbDevices(BSP_MOTOR_CONTROL_BOARD_ID_L6208, 1);
	/* When BSP_MotorControl_Init is called with NULL pointer,                  */
	/* the L6208 parameters are set with the predefined values from file        */
	/* l6208_target_config.h, otherwise the parameters are set using the        */
	/* initDeviceParameters structure values.                                   */
	BSP_MotorControl_Init(BSP_MOTOR_CONTROL_BOARD_ID_L6208, NULL);
	//BSP_MotorControl_Init(BSP_MOTOR_CONTROL_BOARD_ID_L6208, &initDeviceParameters);

	/* Attach the function MyFlagInterruptHandler (defined below) to the flag interrupt */
	BSP_MotorControl_AttachFlagInterrupt(MyFlagInterruptHandler);

	/* Attach the function MyErrorHandler (defined below) to the error Handler*/
	BSP_MotorControl_AttachErrorHandler(MyErrorHandler);

	//----- Configure Button for user interaction

	/* Set Systick Interrupt priority highest to ensure no lock by using HAL_Delay */
	HAL_NVIC_SetPriority(SysTick_IRQn, 0x0, 0x0);

	/* Configure KEY Button */
	BSP_PB_Init(BUTTON_KEY, BUTTON_MODE_EXTI);

	//----- Disable the power bridges after initialization of the L6208 device

	/* Disable the power bridges after initialization */
	BSP_MotorControl_CmdDisable(0);

	/* Wait for 2 seconds */
	HAL_Delay(2000);

	//----- Get the PWM frequency used for the VREFA and VREFB voltage generation

	freqPwm = BSP_MotorControl_GetBridgeInputPwmFreq(0);

	//----- Set the PWM frequency used for the VREFA and VREFB voltage generation

	BSP_MotorControl_SetBridgeInputPwmFreq(0, freqPwm>>1);

	pos = BSP_MotorControl_GetPosition(0);

	BSP_MotorControl_SetHome(0, pos);

	timeToNextStep = (float)(sunWindow / 100) * 60 * 60 * 1000;

	BSP_MotorControl_SelectStepMode(0, STEP_MODE_FULL);

	//BSP_MotorControl_Move(0, FORWARD, 25);
	//BSP_MotorControl_WaitWhileActive(0);

	/* Infinite loop */
	while(1)
	{
		if (gButtonPressed)
		{
			gButtonPressed = FALSE;
			// Sleep for timeToNextStep
			// Shut down motor for timeToNextStep
			// Wake up F401RE and motor after timeToNextStep
			// Make the Step
		}
	BSP_MotorControl_GoHome(0);
	BSP_MotorControl_WaitWhileActive(0);
	HAL_Delay(2000);
	}
}

/**
  * @brief  This function is the User handler for the flag interrupt
  * @param  None
  * @retval None
  */
void MyFlagInterruptHandler(void)
{
  //When EN pin is forced low by a failure, configure the GPIO as an ouput low
  BSP_MotorControl_CmdDisable(0);
}

/**
  * @brief  This function is executed in case of error occurrence.
  * @param  error number of the error
  * @retval None
  */
void MyErrorHandler(uint16_t error)
{
  /* Backup error number */
  gLastError = error;
  
  /* Infinite loop */
  while(1)
  {
  }
}

/**
  * @brief  This function is executed in case of button press and it changes the
  * current direction of the motor
  * @param  None
  * @retval None
  */
void ButtonHandler(void)
{
	gButtonPressed = TRUE;
  /* Let 200 ms before clearing the IT for key debouncing */
	HAL_Delay(200);
	__HAL_GPIO_EXTI_CLEAR_IT(KEY_BUTTON_PIN);
	HAL_NVIC_ClearPendingIRQ(KEY_BUTTON_EXTI_IRQn);
}

void transmit_uart(char *string){
	uint8_t len = strlen(string);
	HAL_UART_Transmit(&huart2, (uint8_t*) string, len, 200);
}


#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  while (1)
  {
  }
}
#endif

/**
  * @}
  */


/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
